@@ -467,6 +467,14 @@ def get_origin_host(headers):
 def append_cors_headers(bucket_name, request_method, request_headers, response):
     bucket_name = normalize_bucket_name(bucket_name)
 
+    # https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Request-Method
+    # > The Access-Control-Request-Method request header is used by browsers when issuing a preflight request,
+    # > to let the server know which HTTP method will be used when the actual request is made.
+    # > This header is necessary as the preflight request is always an OPTIONS and doesn't use the same method
+    # > as the actual request.
+    if request_method == "OPTIONS" and "Access-Control-Request-Method" in request_headers:
+        request_method = request_headers["Access-Control-Request-Method"]
+
     # Checking CORS is allowed or not
     cors = BUCKET_CORS.get(bucket_name)
     if not cors:
@@ -505,21 +513,21 @@ def append_cors_headers(bucket_name, request_method, request_headers, response):
                     response.headers["Access-Control-Allow-Origin"] = origin
                     if "AllowedMethod" in rule:
                         response.headers["Access-Control-Allow-Methods"] = (
-                            ",".join(allowed_methods)
+                            ", ".join(allowed_methods)
                             if isinstance(allowed_methods, list)
                             else allowed_methods
                         )
                     if "AllowedHeader" in rule:
                         allowed_headers = rule["AllowedHeader"]
                         response.headers["Access-Control-Allow-Headers"] = (
-                            ",".join(allowed_headers)
+                            ", ".join(allowed_headers)
                             if isinstance(allowed_headers, list)
                             else allowed_headers
                         )
                     if "ExposeHeader" in rule:
                         expose_headers = rule["ExposeHeader"]
                         response.headers["Access-Control-Expose-Headers"] = (
-                            ",".join(expose_headers)
+                            ", ".join(expose_headers)
                             if isinstance(expose_headers, list)
                             else expose_headers
                         )
